@@ -25,10 +25,19 @@ sub request
 {
   my $s = shift;
   
+  my $uri = '';
+  if( $s->bucket =~ m{[A-Z]} )
+  {
+    $uri = $s->protocol . '://s3.amazonaws.com/' . $s->bucket . '/' . $s->key;
+  }
+  else
+  {
+    $uri = $s->protocol . '://' . $s->bucket . '.s3.amazonaws.com/' . $s->key;
+  }# end if()
   my $signer = AWS::S3::Signer->new(
     s3            => $s->s3,
     method        => 'DELETE',
-    uri           => $s->protocol . '://' . $s->bucket . '.s3.amazonaws.com/' . $s->key,
+    uri           => $uri
   );
   $s->_send_request( $signer->method => $signer->uri => {
     Authorization => $signer->auth_header,
