@@ -18,10 +18,20 @@ sub request
 {
   my $s = shift;
   
+  my $uri = '';
+  if( $s->bucket =~ m{[A-Z]} )
+  {
+    $uri = $s->protocol . '://s3.amazonaws.com/' . $s->bucket . '/?acl';
+  }
+  else
+  {
+    $uri = $s->protocol . '://' . $s->bucket . '.s3.amazonaws.com/?acl';
+  }# end if()
+  
   my $signer = AWS::S3::Signer->new(
     s3            => $s->s3,
     method        => 'GET',
-    uri           => $s->protocol . '://' . $s->bucket . '.s3.amazonaws.com/?acl',
+    uri           => $uri,
   );
   $s->_send_request( $signer->method => $signer->uri => {
     Authorization => $signer->auth_header,
